from dozent.catch_thread_exceptions import install as _catch_thread_exceptions
from dozent.dozent import Dozent

_catch_thread_exceptions()

__all__ = ["Dozent"]
